@@ -35,18 +35,27 @@ QString KisMimeDatabase::mimeTypeForFile(const QString &file)
     QFileInfo fi(file);
     QString suffix = fi.suffix().toLower();
     Q_FOREACH(const KisMimeDatabase::KisMimeType &mimeType, s_mimeDatabase) {
-        if (mimeType.suffixes.contains("*." + suffix)) {
+        if (mimeType.suffixes.contains(suffix)) {
             debugPlugin << "mimeTypeForFile(). KisMimeDatabase returned" << mimeType.mimeType << "for" << file;
             return mimeType.mimeType;
         }
     }
 
     QMimeDatabase db;
-    QMimeType mime = db.mimeTypeForFile(file);
+    QMimeType mime = db.mimeTypeForFile(file, QMimeDatabase::MatchContent);
     if (mime.name() != "application/octet-stream") {
         debugPlugin << "mimeTypeForFile(). QMimeDatabase returned" << mime.name() << "for" << file;
         return mime.name();
     }
+
+    if (mime.name() == "application/octet-stream") {
+        mime = db.mimeTypeForFile(file);
+        if (mime.name() != "application/octet-stream") {
+            debugPlugin << "mimeTypeForFile(). QMimeDatabase returned" << mime.name() << "for" << file;
+            return mime.name();
+        }
+    }
+
     return "";
 }
 
@@ -56,9 +65,6 @@ QString KisMimeDatabase::mimeTypeForSuffix(const QString &suffix)
     QMimeDatabase db;
 
     QString s = suffix.toLower();
-    if (!s.startsWith("*.")) {
-        s = "*." + s;
-    }
 
     Q_FOREACH(const KisMimeDatabase::KisMimeType &mimeType, s_mimeDatabase) {
         if (mimeType.suffixes.contains(s)) {
@@ -67,7 +73,11 @@ QString KisMimeDatabase::mimeTypeForSuffix(const QString &suffix)
         }
     }
 
-    QMimeType mime = db.mimeTypeForFile(s);
+
+    // make the file look like a file so Qt would recognize it
+    s = "file." + s;
+
+    QMimeType mime = db.mimeTypeForName(s);
     if (mime.name() != "application/octet-stream") {
         debugPlugin << "mimeTypeForSuffix(). QMimeDatabase returned" << mime.name() << "for" << s;
         return mime.name();
@@ -154,116 +164,123 @@ void KisMimeDatabase::fillMimeData()
 
         mimeType.mimeType = "image/x-gimp-brush";
         mimeType.description = i18nc("description of a file type", "Gimp Brush");
-        mimeType.suffixes = QStringList() << "*.gbr" << "*.vbr";
+        mimeType.suffixes = QStringList() << "gbr" << "vbr";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-gimp-brush-animated";
         mimeType.description = i18nc("description of a file type", "Gimp Image Hose Brush");
-        mimeType.suffixes = QStringList() << "*.gih";
+        mimeType.suffixes = QStringList() << "gih";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-adobe-brushlibrary";
         mimeType.description = i18nc("description of a file type", "Adobe Brush Library");
-        mimeType.suffixes = QStringList() << "*.abr";
+        mimeType.suffixes = QStringList() << "abr";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-paintoppreset";
         mimeType.description = i18nc("description of a file type", "Krita Brush Preset");
-        mimeType.suffixes = QStringList() << "*.kpp";
+        mimeType.suffixes = QStringList() << "kpp";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-assistant";
         mimeType.description = i18nc("description of a file type", "Krita Assistant");
-        mimeType.suffixes = QStringList() << "*.paintingassistant";
+        mimeType.suffixes = QStringList() << "paintingassistant";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "image/x-r32";
+        mimeType.description = i18nc("description of a file type", "R32 Heightmap");
+        mimeType.suffixes = QStringList() <<  "r32";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-r16";
         mimeType.description = i18nc("description of a file type", "R16 Heightmap");
-        mimeType.suffixes = QStringList() <<  "*.r16";
+        mimeType.suffixes = QStringList() <<  "r16";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-r8";
         mimeType.description = i18nc("description of a file type", "R8 Heightmap");
-        mimeType.suffixes = QStringList() << "*.r8";
+        mimeType.suffixes = QStringList() << "r8";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-spriter";
         mimeType.description = i18nc("description of a file type", "Spriter SCML");
-        mimeType.suffixes = QStringList() << "*.scml";
+        mimeType.suffixes = QStringList() << "scml";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-svm";
         mimeType.description = i18nc("description of a file type", "Starview Metafile");
-        mimeType.suffixes = QStringList() << "*.svm";
+        mimeType.suffixes = QStringList() << "svm";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/openraster";
         mimeType.description = i18nc("description of a file type", "OpenRaster Image");
-        mimeType.suffixes = QStringList() << "*.ora";
+        mimeType.suffixes = QStringList() << "ora";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-photoshop-style-library";
         mimeType.description = i18nc("description of a file type", "Photoshop Layer Style Library");
-        mimeType.suffixes = QStringList() << "*.asl";
+        mimeType.suffixes = QStringList() << "asl";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-gimp-color-palette";
         mimeType.description = i18nc("description of a file type", "Color Palette");
-        mimeType.suffixes = QStringList() << "*.gpl" << "*.pal" << "*.act" << "*.aco" << "*.colors" << "*.xml";
+        mimeType.suffixes = QStringList() << "gpl" << "pal" << "act" << "aco" << "colors" << "xml" << "sbz";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-opencolorio-configuration";
         mimeType.description = i18nc("description of a file type", "OpenColorIO Configuration");
-        mimeType.suffixes = QStringList() << "*.ocio";
+        mimeType.suffixes = QStringList() << "ocio";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-recorded-macro";
         mimeType.description = i18nc("description of a file type", "Krita Recorded Action");
-        mimeType.suffixes = QStringList() << "*.krarec";
+        mimeType.suffixes = QStringList() << "krarec";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-gimp-gradient";
         mimeType.description = i18nc("description of a file type", "GIMP Gradients");
-        mimeType.suffixes = QStringList() << "*.ggr";
+        mimeType.suffixes = QStringList() << "ggr";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-gimp-pattern";
         mimeType.description = i18nc("description of a file type", "GIMP Patterns");
-        mimeType.suffixes = QStringList() << "*.pat";
+        mimeType.suffixes = QStringList() << "pat";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-karbon-gradient";
         mimeType.description = i18nc("description of a file type", "Karbon Gradients");
-        mimeType.suffixes = QStringList() << "*.kgr";
+        mimeType.suffixes = QStringList() << "kgr";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-bundle";
         mimeType.description = i18nc("description of a file type", "Krita Resource Bundle");
-        mimeType.suffixes = QStringList() << "*.bundle";
+        mimeType.suffixes = QStringList() << "bundle";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-workspace";
         mimeType.description = i18nc("description of a file type", "Krita Workspace");
-        mimeType.suffixes = QStringList() << "*.kws";
+        mimeType.suffixes = QStringList() << "kws";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-taskset";
         mimeType.description = i18nc("description of a file type", "Krita Taskset");
-        mimeType.suffixes = QStringList() << "*.kts";
+        mimeType.suffixes = QStringList() << "kts";
         s_mimeDatabase << mimeType;
 
-
         mimeType.mimeType = "image/x-krita-raw";
         mimeType.description = i18nc("description of a file type", "Camera Raw Files");
-        mimeType.suffixes = QStringList() << "*.nef" << "*.cr2" << "*.sr2" << "*.crw" << "*.pef" << "*.x3f" << "*.kdc" << "*.mrw" << "*.arw" << "*.k25" << "*.dcr" << "*.orf" << "*.raw" << "*.raw" << "*.raf" << "*.srf" << "*.dng";
+        mimeType.suffixes = QStringList() << "nef" << "cr2" << "sr2" << "crw" << "pef" << "x3f" << "kdc" << "mrw" << "arw" << "k25" << "dcr" << "orf" << "raw" << "raw" << "raf" << "srf" << "dng";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-extension-exr";
         mimeType.description = i18nc("description of a file type", "OpenEXR (Extended)");
-        mimeType.suffixes = QStringList() << "*.exr";
+        mimeType.suffixes = QStringList() << "exr";
         s_mimeDatabase << mimeType;
 
-
+        mimeType.mimeType = "image/x-psb";
+        mimeType.description = i18nc("description of a file type", "Photoshop Image (Large)");
+        mimeType.suffixes = QStringList() << "psb";
+        s_mimeDatabase << mimeType;
 
         debugPlugin << "Filled mimedatabase with" << s_mimeDatabase.count() << "special mimetypes";
     }
