@@ -42,6 +42,7 @@
 #include "kis_icon_utils.h"
 #include "kis_layer_properties_icons.h"
 #include "krita_utils.h"
+#include "kis_config_notifier.h"
 
 typedef KisBaseNode::Property* OptionalProperty;
 
@@ -56,6 +57,9 @@ public:
     QPointer<QWidget> edit;
     KisNodeToolTip tip;
 
+    QColor checkersColor1;
+    QColor checkersColor2;
+
     QList<OptionalProperty> rightmostProperties(const KisBaseNode::PropertyList &props) const;
     int numProperties(const QModelIndex &index) const;
     OptionalProperty findProperty(KisBaseNode::PropertyList &props, const OptionalProperty &refProp) const;
@@ -70,6 +74,8 @@ KisNodeDelegate::KisNodeDelegate(KisNodeView *view, QObject *parent)
 {
     d->view = view;
     QApplication::instance()->installEventFilter(this);
+    connect(KisConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(slotConfigChanged()));
+    slotConfigChanged();
 }
 
 KisNodeDelegate::~KisNodeDelegate()
@@ -276,16 +282,14 @@ void KisNodeDelegate::drawThumbnail(QPainter *p, const QStyleOptionViewItem &opt
     offset.setY((fitRect.height() - img.height()) / 2);
     offset += fitRect.topLeft();
 
-    KisConfig cfg;
-
     // paint in a checkerboard pattern behind the layer contents to represent transparent
     const int step = scm.thumbnailSize() / 6;
     QImage checkers(2 * step, 2 * step, QImage::Format_ARGB32);
     QPainter gc(&checkers);
-    gc.fillRect(QRect(0, 0, step, step), cfg.checkersColor1());
-    gc.fillRect(QRect(step, 0, step, step), cfg.checkersColor2());
-    gc.fillRect(QRect(step, step, step, step), cfg.checkersColor1());
-    gc.fillRect(QRect(0, step, step, step), cfg.checkersColor2());
+    gc.fillRect(QRect(0, 0, step, step), d->checkersColor1);
+    gc.fillRect(QRect(step, 0, step, step), d->checkersColor2);
+    gc.fillRect(QRect(step, step, step, step), d->checkersColor1);
+    gc.fillRect(QRect(0, step, step, step), d->checkersColor2);
 
     QBrush brush(checkers);
     p->setBrushOrigin(offset);
@@ -862,3 +866,11 @@ void KisNodeDelegate::drawProgressBar(QPainter *p, const QStyleOptionViewItem &o
         p->restore();
     }
 }
+
+void KisNodeDelegate::slotConfigChanged()
+{
+    KisConfig cfg;
+
+    d->checkersColor1 = cfg.checkersColor1();
+    d->checkersColor2 = cfg.checkersColor2();
+}
