@@ -341,6 +341,8 @@ KisImageSP KisKraLoader::loadXML(const KoXmlElement& element)
             loadGuides(e);
         } else if (e.tagName() == "assistants") {
             loadAssistantsList(e);
+        } else if (e.tagName() == "audio") {
+            loadAudio(e, image);
         }
     }
 
@@ -794,9 +796,9 @@ KisNodeSP KisKraLoader::loadFileLayer(const KoXmlElement& element, KisImageSP im
         qApp->setOverrideCursor(Qt::ArrowCursor);
         QString msg = i18nc(
             "@info",
-            "The file associated to a file layer with the name \"%1\" is not found.<nl/><nl/>"
-            "Expected path:<nl/>"
-            "%2<nl/><nl/>"
+            "The file associated to a file layer with the name \"%1\" is not found.\n\n"
+            "Expected path:\n>"
+            "%2\n\n"
             "Do you want to locate it manually?", name, fullPath);
 
         int result = QMessageBox::warning(0, i18nc("@title:window", "File not found"), msg, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
@@ -861,7 +863,7 @@ KisNodeSP KisKraLoader::loadAdjustmentLayer(const KoXmlElement& element, KisImag
         return 0; // XXX: We don't have this filter. We should warn about it!
     }
 
-    KisFilterConfigurationSP  kfc = f->defaultConfiguration(0);
+    KisFilterConfigurationSP  kfc = f->defaultConfiguration();
 
     // We'll load the configuration and the selection later.
     layer = new KisAdjustmentLayer(image, name, kfc, 0);
@@ -914,7 +916,7 @@ KisNodeSP KisKraLoader::loadGeneratorLayer(const KoXmlElement& element, KisImage
         return 0; // XXX: We don't have this generator. We should warn about it!
     }
 
-    KisFilterConfigurationSP  kgc = generator->defaultConfiguration(0);
+    KisFilterConfigurationSP  kgc = generator->defaultConfiguration();
 
     // We'll load the configuration and the selection later.
     layer = new KisGeneratorLayer(image, name, kgc, 0);
@@ -976,7 +978,7 @@ KisNodeSP KisKraLoader::loadFilterMask(const KoXmlElement& element, KisNodeSP pa
         return 0; // XXX: We don't have this filter. We should warn about it!
     }
 
-    KisFilterConfigurationSP  kfc = f->defaultConfiguration(0);
+    KisFilterConfigurationSP  kfc = f->defaultConfiguration();
 
     // We'll load the configuration and the selection later.
     mask = new KisFilterMask();
@@ -1102,3 +1104,52 @@ void KisKraLoader::loadGuides(const KoXmlElement& elem)
     guides.loadFromXml(domElement);
     m_d->document->setGuidesConfig(guides);
 }
+
+void KisKraLoader::loadAudio(const KoXmlElement& elem, KisImageSP image)
+{
+    QDomDocument dom;
+    KoXml::asQDomElement(dom, elem);
+    QDomElement qElement = dom.firstChildElement();
+
+    QString fileName;
+    if (KisDomUtils::loadValue(qElement, "masterChannelPath", &fileName)) {
+        fileName = QDir::toNativeSeparators(fileName);
+
+        QDir baseDirectory = QFileInfo(m_d->document->localFilePath()).absoluteDir();
+        fileName = baseDirectory.absoluteFilePath(fileName);
+
+        QFileInfo info(fileName);
+
+        if (!info.exists()) {
+            qApp->setOverrideCursor(Qt::ArrowCursor);
+            QString msg = i18nc(
+                "@info",
+                "Audio channel file \"%1\" doesn't exist!\n\n"
+                "Expected path:\n"
+                "%2\n\n"
+                "Do you want to locate it manually?", info.fileName(), info.absoluteFilePath());
+
+            int result = QMessageBox::warning(0, i18nc("@title:window", "File not found"), msg, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+
+            if (result == QMessageBox::Yes) {
+                info.setFile(KisImportExportManager::askForAudioFileName(info.absolutePath(), 0));
+            }
+
+            qApp->restoreOverrideCursor();
+        }
+
+        if (info.exists()) {
+            image->animationInterface()->setAudioChannelFileName(info.absoluteFilePath());
+        }
+    }
+
+    bool audioMuted = false;
+    if (KisDomUtils::loadValue(qElement, "audioMuted", &audioMuted)) {
+        image->animationInterface()->setAudioMuted(audioMuted);
+    }
+
+    qreal audioVolume = 0.5;
+    if (KisDomUtils::loadValue(qElement, "audioVolume", &audioVolume)) {
+        image->animationInterface()->setAudioVolume(audioVolume);
+    }
+}
