@@ -84,15 +84,21 @@ void KoFileDialog::setCaption(const QString &caption)
     d->caption = caption;
 }
 
-void KoFileDialog::setDefaultDir(const QString &defaultDir)
+void KoFileDialog::setDefaultDir(const QString &defaultDir, bool force)
 {
-    qDebug() << d->defaultDirectory << d->dialogName << getUsedDir(d->dialogName);
-    if (d->defaultDirectory.isEmpty()) {
-        QFileInfo f(defaultDir);
-        d->defaultDirectory = f.absoluteFilePath();
-    }
-    if (!QFileInfo(defaultDir).isDir()) {
-        d->proposedFileName = QFileInfo(defaultDir).fileName();
+    if (!defaultDir.isEmpty()) {
+        if (d->defaultDirectory.isEmpty() || force) {
+            QFileInfo f(defaultDir);
+            if (f.isDir()) {
+                d->defaultDirectory = defaultDir;
+            }
+            else {
+                d->defaultDirectory = f.absolutePath();
+            }
+        }
+        if (!QFileInfo(defaultDir).isDir()) {
+            d->proposedFileName = QFileInfo(defaultDir).fileName();
+        }
     }
 }
 
@@ -106,16 +112,25 @@ void KoFileDialog::setImageFilters()
     setMimeTypeFilters(imageFilters);
 }
 
-void KoFileDialog::setMimeTypeFilters(const QStringList &filterList, QString defaultFilter)
+void KoFileDialog::setMimeTypeFilters(const QStringList &mimeTypeList, QString defaultMimeType)
 {
-    d->filterList = getFilterStringListFromMime(filterList, true);
+    d->filterList = getFilterStringListFromMime(mimeTypeList, true);
 
-    if (!defaultFilter.isEmpty()) {
-        QStringList defaultFilters = getFilterStringListFromMime(QStringList() << defaultFilter, false);
+    QString defaultFilter;
+
+    if (!defaultMimeType.isEmpty()) {
+        QString suffix = KisMimeDatabase::suffixesForMimeType(defaultMimeType).first();
+
+        if (!d->proposedFileName.isEmpty()) {
+            d->proposedFileName = QFileInfo(d->proposedFileName).baseName() + "." + suffix;
+        }
+
+        QStringList defaultFilters = getFilterStringListFromMime(QStringList() << defaultMimeType, false);
         if (defaultFilters.size() > 0) {
             defaultFilter = defaultFilters.first();
         }
     }
+
     d->defaultFilter = defaultFilter;
 }
 
@@ -131,20 +146,17 @@ QString KoFileDialog::selectedMimeType() const
 
 void KoFileDialog::createFileDialog()
 {
-    qDebug() << "createFileDialog. Parent:" << d->parent
-             << "Caption:" << d->caption
-             << "Default directory:" << d->defaultDirectory
-             << "proposed filename" << d->proposedFileName
-             << "Default filter:" << d->defaultFilter;
-
     d->fileDialog.reset(new QFileDialog(d->parent, d->caption, d->defaultDirectory + "/" + d->proposedFileName));
-    bool dontUseNative = false;
+    KConfigGroup group = KSharedConfig::openConfig()->group("File Dialogs");
+
+    bool dontUseNative = true;
 #ifdef Q_OS_UNIX
-    if (qgetenv("XDG_CURRENT_DESKTOP") != "KDE") {
-        dontUseNative = true;
+    if (qgetenv("XDG_CURRENT_DESKTOP") == "KDE") {
+        dontUseNative = false;
     }
 #endif
-    d->fileDialog->setOption(QFileDialog::DontUseNativeDialog, dontUseNative);
+
+    d->fileDialog->setOption(QFileDialog::DontUseNativeDialog, group.readEntry("DontUseNativeFileDialog", dontUseNative));
     d->fileDialog->setOption(QFileDialog::DontConfirmOverwrite, false);
     d->fileDialog->setOption(QFileDialog::HideNameFilterDetails, true);
 
@@ -185,11 +197,9 @@ void KoFileDialog::createFileDialog()
     d->fileDialog->setNameFilters(d->filterList);
 
     if (!d->proposedFileName.isEmpty()) {
-        qDebug() << "Finding the right mimetype for the given file" << d->defaultDirectory;
         QString mime = KisMimeDatabase::mimeTypeForFile(d->proposedFileName);
         QString description = KisMimeDatabase::descriptionForMimeType(mime);
         Q_FOREACH(const QString &filter, d->filterList) {
-            qDebug() << "\tConsidering" << filter;
             if (filter.startsWith(description)) {
                 d->fileDialog->selectNameFilter(filter);
                 break;
@@ -233,7 +243,6 @@ QString KoFileDialog::filename()
                 extension = "." + extension;
             }
             url = url + extension;
-
         }
 
         d->mimeType = KisMimeDatabase::mimeTypeForFile(url);
@@ -398,7 +407,6 @@ QString KoFileDialog::getUsedDir(const QString &dialogName)
 
     KConfigGroup group =  KSharedConfig::openConfig()->group("File Dialogs");
     QString dir = group.readEntry(dialogName, "");
-
     return dir;
 }
 
@@ -407,7 +415,6 @@ void KoFileDialog::saveUsedDir(const QString &fileName,
 {
 
     if (dialogName.isEmpty()) return;
-    if (d->type == SaveFile) return;
 
     QFileInfo fileInfo(fileName);
     KConfigGroup group =  KSharedConfig::openConfig()->group("File Dialogs");
