@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #ifndef WAVELETDECOMPOSE_H
-#define WAVETETDECOMPOSE_H
+#define WAVELETDECOMPOSE_H
 
 #include <QVariant>
 
@@ -29,7 +29,7 @@ class WaveletDecompose : public KisViewPlugin
     Q_OBJECT
 public:
     WaveletDecompose(QObject *parent, const QVariantList &);
-    virtual ~WaveletDecompose();
+    ~WaveletDecompose() override;
 
 private Q_SLOTS:
 
