@@ -30,10 +30,10 @@ class SpiralShapeFactory : public KoShapeFactoryBase
 public:
     /// constructor
     SpiralShapeFactory();
-    ~SpiralShapeFactory() {}
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const;
-    virtual QList<KoShapeConfigWidgetBase *> createShapeOptionPanels();
+    ~SpiralShapeFactory() override {}
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const override;
+    QList<KoShapeConfigWidgetBase *> createShapeOptionPanels() override;
 };
 
 #endif /* KOSPIRALSHAPEFACTORY_H */
