@@ -45,6 +45,8 @@ KisBMPExport::~KisBMPExport()
 
 KisImportExportFilter::ConversionStatus KisBMPExport::convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration)
 {
+    Q_UNUSED(configuration);
+
     dbgFile << "BMP export! From:" << from << ", To:" << to << "";
 
     KisDocument *input = inputDocument();
@@ -58,10 +60,8 @@ KisImportExportFilter::ConversionStatus KisBMPExport::convert(const QByteArray&
     if (from != "application/x-krita")
         return KisImportExportFilter::NotImplemented;
 
-    QRect rc = input->image()->bounds();
-    // the image must be locked at the higher levels
-    KIS_SAFE_ASSERT_RECOVER_NOOP(input->image()->locked());
-    QImage image = input->image()->projection()->convertToQImage(0, 0, 0, rc.width(), rc.height(), KoColorConversionTransformation::internalRenderingIntent(), KoColorConversionTransformation::internalConversionFlags());
+    QRect rc = input->savingImage()->bounds();
+    QImage image = input->savingImage()->projection()->convertToQImage(0, 0, 0, rc.width(), rc.height(), KoColorConversionTransformation::internalRenderingIntent(), KoColorConversionTransformation::internalConversionFlags());
     image.save(filename);
     return KisImportExportFilter::OK;
 }
