@@ -28,9 +28,9 @@ class KisODGImport : public KisImportExportFilter
     Q_OBJECT
 public:
     KisODGImport(QObject *parent, const QVariantList &);
-    virtual ~KisODGImport();
+    ~KisODGImport() override;
 public:
-    virtual KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0);
+    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
 };
 
 #endif
