@@ -64,7 +64,6 @@
 #include <kis_pixel_selection.h>
 #include <kis_shape_selection.h>
 #include <kis_selection_manager.h>
-#include <kis_system_locker.h>
 #include <krita_utils.h>
 #include <kis_resources_snapshot.h>
 
@@ -151,9 +150,7 @@ void KisToolTransform::canvasUpdateRequested()
 
 void KisToolTransform::resetCursorStyle()
 {
-    KisTool::resetCursorStyle();
-
-    overrideCursorIfNotEditable();
+    setFunctionalCursor();
 }
 
 void KisToolTransform::resetRotationCenterButtonsRequested()
@@ -346,9 +343,21 @@ void KisToolTransform::endPrimaryAction(KoPointerEvent *event)
     endActionImpl(event, true, KisTool::NONE);
 }
 
+void KisToolTransform::activatePrimaryAction()
+{
+    currentStrategy()->activatePrimaryAction();
+    setFunctionalCursor();
+}
+
+void KisToolTransform::deactivatePrimaryAction()
+{
+    currentStrategy()->deactivatePrimaryAction();
+}
+
 void KisToolTransform::activateAlternateAction(AlternateAction action)
 {
     currentStrategy()->activateAlternateAction(action);
+    setFunctionalCursor();
 }
 
 void KisToolTransform::deactivateAlternateAction(AlternateAction action)
@@ -382,7 +391,7 @@ void KisToolTransform::mouseMoveEvent(KoPointerEvent *event)
 
     cursorOutlineUpdateRequested(mousePos);
 
-    if (!MOVE_CONDITION(event, KisTool::PAINT_MODE)) {
+    if (this->mode() != KisTool::PAINT_MODE) {
         currentStrategy()->hoverActionCommon(event);
         setFunctionalCursor();
         KisTool::mouseMoveEvent(event);
@@ -395,72 +404,6 @@ void KisToolTransform::mouseReleaseEvent(KoPointerEvent *event)
     KisTool::mouseReleaseEvent(event);
 }
 
-void KisToolTransform::touchEvent( QTouchEvent* event )
-{
-    //Count all moving touch points
-    int touchCount = 0;
-    Q_FOREACH ( QTouchEvent::TouchPoint tp, event->touchPoints() ) {
-        if( tp.state() == Qt::TouchPointMoved ) {
-            touchCount++;
-        }
-    }
-
-    //Use the touch point count to determine the gesture
-    switch( touchCount ) {
-    case 1: { //Panning
-        QTouchEvent::TouchPoint tp = event->touchPoints().at( 0 );
-        QPointF diff = tp.screenPos() - tp.lastScreenPos();
-
-        m_currentArgs.setTransformedCenter( m_currentArgs.transformedCenter() + diff );
-        outlineChanged();
-        break;
-    }
-    case 2: { //Scaling
-        QTouchEvent::TouchPoint tp1 = event->touchPoints().at( 0 );
-        QTouchEvent::TouchPoint tp2 = event->touchPoints().at( 1 );
-
-        float lastZoom = (tp1.lastScreenPos() - tp2.lastScreenPos()).manhattanLength();
-        float newZoom = (tp1.screenPos() - tp2.screenPos()).manhattanLength();
-
-        float diff = (newZoom - lastZoom) / 100;
-
-        m_currentArgs.setScaleX( m_currentArgs.scaleX() + diff );
-        m_currentArgs.setScaleY( m_currentArgs.scaleY() + diff );
-
-        outlineChanged();
-        break;
-    }
-    case 3: { //Rotation
-
-/* TODO: implement touch-based rotation.
-
-            Vector2f center;
-            Q_FOREACH ( const QTouchEvent::TouchPoint &tp, event->touchPoints() ) {
-                if( tp.state() == Qt::TouchPointMoved ) {
-                    center += Vector2f( tp.screenPos().x(), tp.screenPos().y() );
-                }
-            }
-            center /= touchCount;
-
-            QTouchEvent::TouchPoint tp = event->touchPoints().at(0);
-
-            Vector2f oldPosition = (Vector2f( tp.lastScreenPos().x(), tp.lastScreenPos().y() ) - center).normalized();
-            Vector2f newPosition = (Vector2f( tp.screenPos().x(), tp.screenPos().y() ) - center).normalized();
-
-            float oldAngle = qAcos( oldPosition.dot( Vector2f( 0.0f, 0.0f ) ) );
-            float newAngle = qAcos( newPosition.dot( Vector2f( 0.0f, 0.0f ) ) );
-
-            float diff = newAngle - oldAngle;
-
-            m_currentArgs.setAZ( m_currentArgs.aZ() + diff );
-
-            outlineChanged();
-*/
-        break;
-    }
-    }
-}
-
 void KisToolTransform::applyTransform()
 {
     slotApplyTransform();
